@@ -17,7 +17,10 @@ class MilkmanRegistry(object):
     def register():
         registry = MilkmanRegistry()
         registry.add_generator(models.AutoField, generators.random_auto_field_maker)
-        registry.add_generator(models.BigIntegerField, generators.random_big_integer_maker)
+        try:
+            registry.add_generator(models.BigIntegerField, generators.random_big_integer_maker)
+        except AttributeError:
+            pass  # Only supported in django 1.2+
         registry.add_generator(models.BooleanField, generators.random_boolean_maker)
         registry.add_generator(models.CharField, generators.random_string_maker)
         registry.add_generator(models.CommaSeparatedIntegerField, generators.random_comma_seperated_integer_maker)
@@ -33,12 +36,12 @@ class MilkmanRegistry(object):
         registry.add_generator(models.PositiveSmallIntegerField, generators.random_small_positive_integer_maker)
         registry.add_generator(models.SlugField, generators.random_string_maker)
         registry.add_generator(models.SmallIntegerField, generators.random_small_integer_maker)
+        registry.add_generator(models.TextField, generators.random_string_maker)
         registry.add_generator(models.TimeField, generators.random_time_string_maker)
+        # registry.add_generator(models.URLField, generators.random_url_maker)
         # registry.add_generator(models.FileField, default_generator)
         # registry.add_generator(models.FilePathField, default_generator)
         # registry.add_generator(models.ImageField, default_generator)
-        # registry.add_generator(models.TextField, default_generator)
-        # registry.add_generator(models.URLField, default_generator)
         # registry.add_generator(models.XMLField, default_generator)
         return registry
 
@@ -67,7 +70,11 @@ class MilkTruck(object):
         return field in [f.name for f in self.model_class._meta.local_many_to_many]
     
     def has_explicit_through_table(self, field):
-        return not field.rel.through._meta.auto_created
+        if isinstance(field.rel.through, models.base.ModelBase):  # Django 1.2
+            return not field.rel.through._meta.auto_created
+        if isinstance(field.rel.through, (str, unicode)):  # Django 1.1
+            return True
+        return False
     
     def set_explicit_values(self, target, explicit_values):
         for k,v in explicit_values.iteritems():
